@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2007 by FlashCode <flashcode@flashtux.org>
+ * Copyright (c) 2003-2009 by FlashCode <flashcode@flashtux.org>
  * See README for License detail, AUTHORS for developers list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,15 +26,13 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "../../common/weechat.h"
-#include "../gui.h"
-#include "../../common/utf8.h"
+#include "../../core/weechat.h"
+#include "../../core/wee-utf8.h"
+#include "../../plugins/plugin.h"
+#include "../gui-keyboard.h"
+#include "../gui-buffer.h"
 #include "gui-gtk.h"
 
-#ifdef PLUGINS
-#include "../../plugins/plugins.h"
-#endif
-
 
 /*
  * gui_keyboard_default_bindings: create default key bindings
