@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2007 by FlashCode <flashcode@flashtux.org>
+ * Copyright (c) 2003-2009 by FlashCode <flashcode@flashtux.org>
  * See README for License detail, AUTHORS for developers list.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,11 +26,17 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "../../common/weechat.h"
-#include "../gui.h"
-#include "../../common/hotlist.h"
-#include "../../common/log.h"
-#include "../../common/weeconfig.h"
+#include "../../core/weechat.h"
+#include "../../core/wee-config.h"
+#include "../../core/wee-log.h"
+#include "../gui-window.h"
+#include "../gui-bar.h"
+#include "../gui-buffer.h"
+#include "../gui-chat.h"
+#include "../gui-hotlist.h"
+#include "../gui-line.h"
+#include "../gui-nicklist.h"
+#include "../gui-main.h"
 #include "gui-gtk.h"
 
 
@@ -59,23 +65,19 @@ gui_window_get_height ()
  */
 
 int
-gui_window_objects_init (t_gui_window *window)
+gui_window_objects_init (struct t_gui_window *window)
 {
-    t_gui_gtk_objects *new_objects;
-
-    if ((new_objects = (t_gui_gtk_objects *) malloc (sizeof (t_gui_gtk_objects))))
+    struct t_gui_window_gtk_objects *new_objects;
+    
+    if ((new_objects = malloc (sizeof (*new_objects))))
     {
         window->gui_objects = new_objects;
-        GUI_GTK(window)->textview_chat = NULL;
-        GUI_GTK(window)->textbuffer_chat = NULL;
-        GUI_GTK(window)->texttag_chat = NULL;
-        GUI_GTK(window)->textview_nicklist = NULL;
-        GUI_GTK(window)->textbuffer_nicklist = NULL;
-        GUI_GTK(window)->panel_windows = NULL;
+        GUI_WINDOW_OBJECTS(window)->textview_chat = NULL;
+        GUI_WINDOW_OBJECTS(window)->textbuffer_chat = NULL;
+        GUI_WINDOW_OBJECTS(window)->texttag_chat = NULL;
         return 1;
     }
-    else
-        return 0;
+    return 0;
 }
 
 /*
@@ -83,7 +85,7 @@ gui_window_objects_init (t_gui_window *window)
  */
 
 void
-gui_window_objects_free (t_gui_window *window, int free_separator)
+gui_window_objects_free (struct t_gui_window *window, int free_separator)
 {
     /* TODO: write this function for Gtk */
     (void) window;
@@ -110,14 +112,11 @@ gui_window_set_weechat_color (WINDOW *window, int num_color)
  * gui_window_calculate_pos_size: calculate position and size for a window & sub-win
  */
 
-int
-gui_window_calculate_pos_size (t_gui_window *window, int force_calculate)
+void
+gui_window_calculate_pos_size (struct t_gui_window *window)
 {
     /* TODO: write this function for Gtk */
     (void) window;
-    (void) force_calculate;
-    
-    return 0;
 }
 
 /*
@@ -125,7 +124,7 @@ gui_window_calculate_pos_size (t_gui_window *window, int force_calculate)
  */
 
 void
-gui_window_draw_separator (t_gui_window *window)
+gui_window_draw_separator (struct t_gui_window *window)
 {
     /* TODO: write this function for Gtk */
     /*if (window->win_separator)
@@ -150,7 +149,7 @@ gui_window_draw_separator (t_gui_window *window)
  */
 
 void
-gui_window_redraw_buffer (t_gui_buffer *buffer)
+gui_window_redraw_buffer (struct t_gui_buffer *buffer)
 {
     /* TODO: write this function for Gtk */
     (void) buffer;
@@ -166,63 +165,89 @@ gui_window_redraw_all_buffers ()
     /* TODO: write this function for Gtk */
 }
 
+/*
+ * gui_window_switch: switch to another window
+ */
+
+void
+gui_window_switch (struct t_gui_window *window)
+{
+    if (gui_current_window == window)
+        return;
+    
+    /* remove unused bars from current window */
+    /* ... */
+    
+    gui_current_window = window;
+    
+    gui_window_switch_to_buffer (gui_current_window, gui_current_window->buffer, 1);
+    
+    gui_window_redraw_buffer (gui_current_window->buffer);
+}
+
 /*
  * gui_window_switch_to_buffer: switch to another buffer
  */
 
 void
-gui_window_switch_to_buffer (t_gui_window *window, t_gui_buffer *buffer)
+gui_window_switch_to_buffer (struct t_gui_window *window,
+                             struct t_gui_buffer *buffer,
+                             int set_last_read)
 {
     GtkTextIter start, end;
     
-    if (window->buffer->num_displayed > 0)
-        window->buffer->num_displayed--;
+    gui_buffer_add_value_num_displayed (window->buffer, -1);
     
     if (window->buffer != buffer)
     {
-        window->buffer->last_read_line = window->buffer->last_line;
-        if (buffer->last_read_line == buffer->last_line)
-            buffer->last_read_line = NULL;
+        window->start_line = NULL;
+        window->start_line_pos = 0;
+        if (!gui_buffers_visited_frozen)
+        {
+            gui_buffer_visited_add (window->buffer);
+            gui_buffer_visited_add (buffer);
+        }
+        if (set_last_read)
+        {
+            if (window->buffer->num_displayed == 0)
+            {
+                window->buffer->lines->last_read_line = window->buffer->lines->last_line;
+                window->buffer->lines->first_line_not_read = 0;
+            }
+            if (buffer->lines->last_read_line == buffer->lines->last_line)
+            {
+                buffer->lines->last_read_line = NULL;
+                buffer->lines->first_line_not_read = 0;
+            }
+        }
     }
     
     window->buffer = buffer;
-    window->win_nick_start = 0;
-    gui_window_calculate_pos_size (window, 1);
+    gui_window_calculate_pos_size (window);
     
-    if (!GUI_GTK(window)->textview_chat)
+    if (!GUI_WINDOW_OBJECTS(window)->textview_chat)
     {
-        GUI_GTK(window)->textview_chat = gtk_text_view_new ();
-        gtk_widget_show (GUI_GTK(window)->textview_chat);
-        gtk_container_add (GTK_CONTAINER (gui_gtk_scrolledwindow_chat), GUI_GTK(window)->textview_chat);
-        gtk_widget_set_size_request (GUI_GTK(window)->textview_chat, 300, -1);
-        gtk_text_view_set_editable (GTK_TEXT_VIEW (GUI_GTK(window)->textview_chat), FALSE);
-        gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (GUI_GTK(window)->textview_chat), FALSE);
+        GUI_WINDOW_OBJECTS(window)->textview_chat = gtk_text_view_new ();
+        gtk_widget_show (GUI_WINDOW_OBJECTS(window)->textview_chat);
+        gtk_container_add (GTK_CONTAINER (gui_gtk_scrolledwindow_chat), GUI_WINDOW_OBJECTS(window)->textview_chat);
+        gtk_widget_set_size_request (GUI_WINDOW_OBJECTS(window)->textview_chat, 300, -1);
+        gtk_text_view_set_editable (GTK_TEXT_VIEW (GUI_WINDOW_OBJECTS(window)->textview_chat), FALSE);
+        gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (GUI_WINDOW_OBJECTS(window)->textview_chat), FALSE);
         
-        GUI_GTK(window)->textbuffer_chat = gtk_text_buffer_new (NULL);
-        gtk_text_view_set_buffer (GTK_TEXT_VIEW (GUI_GTK(window)->textview_chat), GUI_GTK(window)->textbuffer_chat);
+        GUI_WINDOW_OBJECTS(window)->textbuffer_chat = gtk_text_buffer_new (NULL);
+        gtk_text_view_set_buffer (GTK_TEXT_VIEW (GUI_WINDOW_OBJECTS(window)->textview_chat), GUI_WINDOW_OBJECTS(window)->textbuffer_chat);
         
-        /*GUI_GTK(window)->texttag_chat = gtk_text_buffer_create_tag(GUI_GTK(window)->textbuffer_chat, "courier", "font_family", "lucida");*/
-        gtk_text_buffer_get_bounds (GUI_GTK(window)->textbuffer_chat, &start, &end);
-        gtk_text_buffer_apply_tag (GUI_GTK(window)->textbuffer_chat, GUI_GTK(window)->texttag_chat, &start, &end);
-    }
-    if (GUI_BUFFER_IS_CHANNEL(buffer) && !GUI_GTK(window)->textbuffer_nicklist)
-    {
-        GUI_GTK(window)->textview_nicklist = gtk_text_view_new ();
-        gtk_widget_show (GUI_GTK(window)->textview_nicklist);
-        gtk_container_add (GTK_CONTAINER (gui_gtk_scrolledwindow_nick), GUI_GTK(window)->textview_nicklist);
-        gtk_text_view_set_editable (GTK_TEXT_VIEW (GUI_GTK(window)->textview_nicklist), FALSE);
-        gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (GUI_GTK(window)->textview_nicklist), FALSE);
-        
-        GUI_GTK(window)->textbuffer_nicklist = gtk_text_buffer_new (NULL);
-        gtk_text_view_set_buffer (GTK_TEXT_VIEW (GUI_GTK(window)->textview_nicklist), GUI_GTK(window)->textbuffer_nicklist);
+        /*GUI_WINDOW_OBJECTS(window)->texttag_chat = gtk_text_buffer_create_tag(GUI_WINDOW_OBJECTS(window)->textbuffer_chat, "courier", "font_family", "lucida");*/
+        gtk_text_buffer_get_bounds (GUI_WINDOW_OBJECTS(window)->textbuffer_chat, &start, &end);
+        gtk_text_buffer_apply_tag (GUI_WINDOW_OBJECTS(window)->textbuffer_chat, GUI_WINDOW_OBJECTS(window)->texttag_chat, &start, &end);
     }
     
     window->start_line = NULL;
     window->start_line_pos = 0;
     
-    buffer->num_displayed++;
+    gui_buffer_add_value_num_displayed (buffer, 1);
     
-    hotlist_remove_buffer (buffer);
+    gui_hotlist_remove_buffer (buffer);
 }
 
 /*
@@ -230,7 +255,7 @@ gui_window_switch_to_buffer (t_gui_window *window, t_gui_buffer *buffer)
  */
 
 void
-gui_window_page_up (t_gui_window *window)
+gui_window_page_up (struct t_gui_window *window)
 {
     if (!gui_ok)
         return;
@@ -243,7 +268,6 @@ gui_window_page_up (t_gui_window *window)
                                       (-1) * (window->win_chat_height - 1) :
                                       (-1) * ((window->win_chat_height - 1) * 2));
         gui_chat_draw (window->buffer, 0);
-        gui_status_draw (window->buffer, 0);
     }
 }
 
@@ -252,9 +276,9 @@ gui_window_page_up (t_gui_window *window)
  */
 
 void
-gui_window_page_down (t_gui_window *window)
+gui_window_page_down (struct t_gui_window *window)
 {
-    t_gui_line *ptr_line;
+    struct t_gui_line *ptr_line;
     int line_pos;
     
     if (!gui_ok)
@@ -279,7 +303,6 @@ gui_window_page_down (t_gui_window *window)
         }
         
         gui_chat_draw (window->buffer, 0);
-        gui_status_draw (window->buffer, 0);
     }
 }
 
@@ -288,7 +311,7 @@ gui_window_page_down (t_gui_window *window)
  */
 
 void
-gui_window_scroll_up (t_gui_window *window)
+gui_window_scroll_up (struct t_gui_window *window)
 {
     if (!gui_ok)
         return;
@@ -298,10 +321,10 @@ gui_window_scroll_up (t_gui_window *window)
         gui_chat_calculate_line_diff (window, &window->start_line,
                                       &window->start_line_pos,
                                       (window->start_line) ?
-                                      (-1) * cfg_look_scroll_amount :
-                                      (-1) * ( (window->win_chat_height - 1) + cfg_look_scroll_amount));
+                                      (-1) * CONFIG_INTEGER(config_look_scroll_amount) :
+                                      (-1) * ( (window->win_chat_height - 1) +
+                                               CONFIG_INTEGER(config_look_scroll_amount)));
         gui_chat_draw (window->buffer, 0);
-        gui_status_draw (window->buffer, 0);
     }
 }
 
@@ -310,9 +333,9 @@ gui_window_scroll_up (t_gui_window *window)
  */
 
 void
-gui_window_scroll_down (t_gui_window *window)
+gui_window_scroll_down (struct t_gui_window *window)
 {
-    t_gui_line *ptr_line;
+    struct t_gui_line *ptr_line;
     int line_pos;
     
     if (!gui_ok)
@@ -322,7 +345,7 @@ gui_window_scroll_down (t_gui_window *window)
     {
         gui_chat_calculate_line_diff (window, &window->start_line,
                                       &window->start_line_pos,
-                                      cfg_look_scroll_amount);
+                                      CONFIG_INTEGER(config_look_scroll_amount));
         
         /* check if we can display all */
         ptr_line = window->start_line;
@@ -338,7 +361,6 @@ gui_window_scroll_down (t_gui_window *window)
         }
         
         gui_chat_draw (window->buffer, 0);
-        gui_status_draw (window->buffer, 0);
     }
 }
 
@@ -347,17 +369,16 @@ gui_window_scroll_down (t_gui_window *window)
  */
 
 void
-gui_window_scroll_top (t_gui_window *window)
+gui_window_scroll_top (struct t_gui_window *window)
 {
     if (!gui_ok)
         return;
     
     if (!window->first_line_displayed)
     {
-        window->start_line = window->buffer->lines;
+        window->start_line = window->buffer->lines->first_line;
         window->start_line_pos = 0;
         gui_chat_draw (window->buffer, 0);
-        gui_status_draw (window->buffer, 0);
     }
 }
 
@@ -366,7 +387,7 @@ gui_window_scroll_top (t_gui_window *window)
  */
 
 void
-gui_window_scroll_bottom (t_gui_window *window)
+gui_window_scroll_bottom (struct t_gui_window *window)
 {
     if (!gui_ok)
         return;
@@ -376,134 +397,6 @@ gui_window_scroll_bottom (t_gui_window *window)
         window->start_line = NULL;
         window->start_line_pos = 0;
         gui_chat_draw (window->buffer, 0);
-        gui_status_draw (window->buffer, 0);
-    }
-}
-
-/*
- * gui_window_scroll_topic_left: scroll left topic
- */
-
-void
-gui_window_scroll_topic_left (t_gui_window *window)
-{
-    if (!gui_ok)
-        return;
-    
-    if (window->win_title_start > 0)
-        window->win_title_start -= (window->win_width * 3) / 4;
-    if (window->win_title_start < 0)
-        window->win_title_start = 0;
-    gui_chat_draw_title (window->buffer, 1);
-}
-
-/*
- * gui_window_scroll_topic_right: scroll right topic
- */
-
-void
-gui_window_scroll_topic_right (t_gui_window *window)
-{
-    if (!gui_ok)
-        return;
-    
-    window->win_title_start += (window->win_width * 3) / 4;
-    gui_chat_draw_title (window->buffer, 1);
-}
-
-/*
- * gui_window_nick_beginning: go to beginning of nicklist
- */
-
-void
-gui_window_nick_beginning (t_gui_window *window)
-{
-    if (!gui_ok)
-        return;
-    
-    if (GUI_BUFFER_HAS_NICKLIST(window->buffer))
-    {
-        if (window->win_nick_start > 0)
-        {
-            window->win_nick_start = 0;
-            gui_nicklist_draw (window->buffer, 1, 0);
-        }
-    }
-}
-
-/*
- * gui_window_nick_end: go to the end of nicklist
- */
-
-void
-gui_window_nick_end (t_gui_window *window)
-{
-    int new_start;
-    
-    if (!gui_ok)
-        return;
-    
-    if (GUI_BUFFER_HAS_NICKLIST(window->buffer))
-    {
-        new_start =
-            GUI_CHANNEL(window->buffer)->nicks_count - window->win_nick_height;
-        if (new_start < 0)
-            new_start = 0;
-        else if (new_start >= 1)
-            new_start++;
-        
-        if (new_start != window->win_nick_start)
-        {
-            window->win_nick_start = new_start;
-            gui_nicklist_draw (window->buffer, 1, 0);
-        }
-    }
-}
-
-/*
- * gui_window_nick_page_up: scroll one page up in nicklist
- */
-
-void
-gui_window_nick_page_up (t_gui_window *window)
-{
-    if (!gui_ok)
-        return;
-    
-    if (GUI_BUFFER_HAS_NICKLIST(window->buffer))
-    {
-        if (window->win_nick_start > 0)
-        {
-            window->win_nick_start -= (window->win_nick_height - 1);
-            if (window->win_nick_start <= 1)
-                window->win_nick_start = 0;
-            gui_nicklist_draw (window->buffer, 1, 0);
-        }
-    }
-}
-
-/*
- * gui_window_nick_page_down: scroll one page down in nicklist
- */
-
-void
-gui_window_nick_page_down (t_gui_window *window)
-{
-    if (!gui_ok)
-        return;
-    
-    if (GUI_BUFFER_HAS_NICKLIST(window->buffer))
-    {
-        if ((GUI_CHANNEL(window->buffer)->nicks_count > window->win_nick_height)
-            && (window->win_nick_start + window->win_nick_height - 1
-                < GUI_CHANNEL(window->buffer)->nicks_count))
-        {
-            if (window->win_nick_start == 0)
-                window->win_nick_start += (window->win_nick_height - 1);
-            else
-                window->win_nick_start += (window->win_nick_height - 2);
-            gui_nicklist_draw (window->buffer, 1, 0);
-        }
     }
 }
 
@@ -515,7 +408,7 @@ gui_window_nick_page_down (t_gui_window *window)
  */
 
 int
-gui_window_auto_resize (t_gui_window_tree *tree,
+gui_window_auto_resize (struct t_gui_window_tree *tree,
                         int x, int y, int width, int height,
                         int simulate)
 {
@@ -535,7 +428,7 @@ gui_window_auto_resize (t_gui_window_tree *tree,
         }
         else
         {
-            if (tree->split_horiz)
+            if (tree->split_horizontal)
             {
                 size1 = (height * tree->split_pct) / 100;
                 size2 = height - size1;
@@ -569,7 +462,7 @@ gui_window_auto_resize (t_gui_window_tree *tree,
 void
 gui_window_refresh_windows ()
 {
-    /*t_gui_window *ptr_win, *old_current_window;*/
+    /*struct t_gui_window *ptr_win, *old_current_window;*/
     
     if (gui_ok)
     {
@@ -578,87 +471,95 @@ gui_window_refresh_windows ()
 }
 
 /*
- * gui_window_split_horiz: split a window horizontally
+ * gui_window_split_horizontal: split a window horizontally
  */
 
-void
-gui_window_split_horiz (t_gui_window *window, int pourcentage)
+struct t_gui_window *
+gui_window_split_horizontal (struct t_gui_window *window, int percentage)
 {
-    t_gui_window *new_window;
+    struct t_gui_window *new_window;
     int height1, height2;
     
     if (!gui_ok)
-        return;
+        return NULL;
     
-    height1 = (window->win_height * pourcentage) / 100;
+    new_window = NULL;
+    
+    height1 = (window->win_height * percentage) / 100;
     height2 = window->win_height - height1;
     
-    if ((pourcentage > 0) && (pourcentage <= 100))
+    if ((percentage > 0) && (percentage <= 100))
     {
-        if ((new_window = gui_window_new (window,
-                                          window->win_x, window->win_y,
-                                          window->win_width, height1,
-                                          100, pourcentage)))
+        new_window = gui_window_new (window, window->buffer, 
+                                     window->win_x, window->win_y,
+                                     window->win_width, height1,
+                                     100, percentage);
+        if (new_window)
         {
             /* reduce old window height (bottom window) */
             window->win_y = new_window->win_y + new_window->win_height;
             window->win_height = height2;
-            window->win_height_pct = 100 - pourcentage;
+            window->win_height_pct = 100 - percentage;
             
             /* assign same buffer for new window (top window) */
-            new_window->buffer = window->buffer;
-            new_window->buffer->num_displayed++;
+            gui_buffer_add_value_num_displayed (new_window->buffer, 1);
             
-            gui_window_switch_to_buffer (window, window->buffer);
+            gui_window_switch_to_buffer (window, window->buffer, 1);
             
             gui_current_window = new_window;
-            gui_window_switch_to_buffer (gui_current_window, gui_current_window->buffer);
+            gui_window_switch_to_buffer (gui_current_window, gui_current_window->buffer, 1);
             gui_window_redraw_buffer (gui_current_window->buffer);
         }
     }
+    
+    return new_window;
 }
 
 /*
- * gui_window_split_vertic: split a window vertically
+ * gui_window_split_vertical: split a window vertically
  */
 
-void
-gui_window_split_vertic (t_gui_window *window, int pourcentage)
+struct t_gui_window *
+gui_window_split_vertical (struct t_gui_window *window, int percentage)
 {
-    t_gui_window *new_window;
+    struct t_gui_window *new_window;
     int width1, width2;
     
     if (!gui_ok)
-        return;
+        return NULL;
     
-    width1 = (window->win_width * pourcentage) / 100;
+    new_window = NULL;
+    
+    width1 = (window->win_width * percentage) / 100;
     width2 = window->win_width - width1 - 1;
     
-    if ((pourcentage > 0) && (pourcentage <= 100))
+    if ((percentage > 0) && (percentage <= 100))
     {
-        if ((new_window = gui_window_new (window,
-                                          window->win_x + width1 + 1, window->win_y,
-                                          width2, window->win_height,
-                                          pourcentage, 100)))
+        new_window = gui_window_new (window, window->buffer,
+                                     window->win_x + width1 + 1, window->win_y,
+                                     width2, window->win_height,
+                                     percentage, 100);
+        if (new_window)
         {
             /* reduce old window height (left window) */
             window->win_width = width1;
-            window->win_width_pct = 100 - pourcentage;
+            window->win_width_pct = 100 - percentage;
             
             /* assign same buffer for new window (right window) */
-            new_window->buffer = window->buffer;
-            new_window->buffer->num_displayed++;
+            gui_buffer_add_value_num_displayed (new_window->buffer, 1);
             
-            gui_window_switch_to_buffer (window, window->buffer);
+            gui_window_switch_to_buffer (window, window->buffer, 1);
             
             gui_current_window = new_window;
-            gui_window_switch_to_buffer (gui_current_window, gui_current_window->buffer);
+            gui_window_switch_to_buffer (gui_current_window, gui_current_window->buffer, 1);
             gui_window_redraw_buffer (gui_current_window->buffer);
             
             /* create & draw separator */
             gui_window_draw_separator (gui_current_window);
         }
     }
+    
+    return new_window;
 }
 
 /*
@@ -666,11 +567,11 @@ gui_window_split_vertic (t_gui_window *window, int pourcentage)
  */
 
 void
-gui_window_resize (t_gui_window *window, int pourcentage)
+gui_window_resize (struct t_gui_window *window, int percentage)
 {
     /* TODO: write this function for Gtk */
     (void) window;
-    (void) pourcentage;
+    (void) percentage;
 }
 
 /*
@@ -678,9 +579,9 @@ gui_window_resize (t_gui_window *window, int pourcentage)
  */
 
 int
-gui_window_merge (t_gui_window *window)
+gui_window_merge (struct t_gui_window *window)
 {
-    t_gui_window_tree *parent, *sister;
+    struct t_gui_window_tree *parent, *sister;
     
     parent = window->ptr_tree->parent_node;
     if (parent)
@@ -711,7 +612,7 @@ gui_window_merge (t_gui_window *window)
         gui_window_free (sister->window);
         gui_window_tree_node_to_leaf (parent, window);
         
-        gui_window_switch_to_buffer (window, window->buffer);
+        gui_window_switch_to_buffer (window, window->buffer, 1);
         gui_window_redraw_buffer (window->buffer);
         return 1;
     }
@@ -723,7 +624,7 @@ gui_window_merge (t_gui_window *window)
  */
 
 void
-gui_window_merge_all (t_gui_window *window)
+gui_window_merge_all (struct t_gui_window *window)
 {
     /* TODO: write this function for Gtk */
     (void) window;
@@ -739,7 +640,7 @@ gui_window_merge_all (t_gui_window *window)
  */
 
 int
-gui_window_side_by_side (t_gui_window *win1, t_gui_window *win2)
+gui_window_side_by_side (struct t_gui_window *win1, struct t_gui_window *win2)
 {
     /* win2 over win1 ? */
     if (win2->win_y + win2->win_height == win1->win_y)
@@ -789,9 +690,9 @@ gui_window_side_by_side (t_gui_window *win1, t_gui_window *win2)
  */
 
 void
-gui_window_switch_up (t_gui_window *window)
+gui_window_switch_up (struct t_gui_window *window)
 {
-    t_gui_window *ptr_win;
+    struct t_gui_window *ptr_win;
     
     for (ptr_win = gui_windows; ptr_win;
          ptr_win = ptr_win->next_window)
@@ -800,7 +701,7 @@ gui_window_switch_up (t_gui_window *window)
             (gui_window_side_by_side (window, ptr_win) == 1))
         {
             gui_current_window = ptr_win;
-            gui_window_switch_to_buffer (gui_current_window, gui_current_window->buffer);
+            gui_window_switch_to_buffer (gui_current_window, gui_current_window->buffer, 1);
             gui_window_redraw_buffer (gui_current_window->buffer);
             return;
         }
@@ -812,9 +713,9 @@ gui_window_switch_up (t_gui_window *window)
  */
 
 void
-gui_window_switch_down (t_gui_window *window)
+gui_window_switch_down (struct t_gui_window *window)
 {
-    t_gui_window *ptr_win;
+    struct t_gui_window *ptr_win;
     
     for (ptr_win = gui_windows; ptr_win;
          ptr_win = ptr_win->next_window)
@@ -823,7 +724,7 @@ gui_window_switch_down (t_gui_window *window)
             (gui_window_side_by_side (window, ptr_win) == 3))
         {
             gui_current_window = ptr_win;
-            gui_window_switch_to_buffer (gui_current_window, gui_current_window->buffer);
+            gui_window_switch_to_buffer (gui_current_window, gui_current_window->buffer, 1);
             gui_window_redraw_buffer (gui_current_window->buffer);
             return;
         }
@@ -835,9 +736,9 @@ gui_window_switch_down (t_gui_window *window)
  */
 
 void
-gui_window_switch_left (t_gui_window *window)
+gui_window_switch_left (struct t_gui_window *window)
 {
-    t_gui_window *ptr_win;
+    struct t_gui_window *ptr_win;
     
     for (ptr_win = gui_windows; ptr_win;
          ptr_win = ptr_win->next_window)
@@ -846,7 +747,7 @@ gui_window_switch_left (t_gui_window *window)
             (gui_window_side_by_side (window, ptr_win) == 4))
         {
             gui_current_window = ptr_win;
-            gui_window_switch_to_buffer (gui_current_window, gui_current_window->buffer);
+            gui_window_switch_to_buffer (gui_current_window, gui_current_window->buffer, 1);
             gui_window_redraw_buffer (gui_current_window->buffer);
             return;
         }
@@ -858,9 +759,9 @@ gui_window_switch_left (t_gui_window *window)
  */
 
 void
-gui_window_switch_right (t_gui_window *window)
+gui_window_switch_right (struct t_gui_window *window)
 {
-    t_gui_window *ptr_win;
+    struct t_gui_window *ptr_win;
     
     for (ptr_win = gui_windows; ptr_win;
          ptr_win = ptr_win->next_window)
@@ -869,7 +770,7 @@ gui_window_switch_right (t_gui_window *window)
             (gui_window_side_by_side (window, ptr_win) == 2))
         {
             gui_current_window = ptr_win;
-            gui_window_switch_to_buffer (gui_current_window, gui_current_window->buffer);
+            gui_window_switch_to_buffer (gui_current_window, gui_current_window->buffer, 1);
             gui_window_redraw_buffer (gui_current_window->buffer);
             return;
         }
@@ -881,8 +782,10 @@ gui_window_switch_right (t_gui_window *window)
  */
 
 void
-gui_window_refresh_screen ()
+gui_window_refresh_screen (int full_refresh)
 {
+    (void) full_refresh;
+    
     /* TODO: write this function for Gtk */
 }
 
@@ -891,32 +794,29 @@ gui_window_refresh_screen ()
  */
 
 void
-gui_window_set_title ()
+gui_window_set_title (const char *title)
 {
+    (void) title;
+    
     /* TODO: write this function for Gtk */
 }
 
-/*
- * gui_window_reset_title: reset terminal title
- */
-
-void
-gui_window_reset_title ()
-{
-    /* This function does nothing in Gtk GUI */
-}
-
 /*
  * gui_window_objects_print_log: print Gtk objects infos in log
  *                               (usually for crash dump)
  */
 
 void
-gui_window_objects_print_log (t_gui_window *window)
+gui_window_objects_print_log (struct t_gui_window *window)
 {
-    weechat_log_printf ("  textview_chat . . . : 0x%X\n", GUI_GTK(window)->textview_chat);
-    weechat_log_printf ("  textbuffer_chat . . : 0x%X\n", GUI_GTK(window)->textbuffer_chat);
-    weechat_log_printf ("  texttag_chat. . . . : 0x%X\n", GUI_GTK(window)->texttag_chat);
-    weechat_log_printf ("  textview_nicklist . : 0x%X\n", GUI_GTK(window)->textview_nicklist);
-    weechat_log_printf ("  textbuffer_nicklist : 0x%X\n", GUI_GTK(window)->textbuffer_nicklist);
+    log_printf ("  window specific objects for Gtk:");
+    log_printf ("    textview_chat . . . : 0x%lx", GUI_WINDOW_OBJECTS(window)->textview_chat);
+    log_printf ("    textbuffer_chat . . : 0x%lx", GUI_WINDOW_OBJECTS(window)->textbuffer_chat);
+    log_printf ("    texttag_chat. . . . : 0x%lx", GUI_WINDOW_OBJECTS(window)->texttag_chat);
+    log_printf ("    bar_windows . . . . : 0x%lx", GUI_WINDOW_OBJECTS(window)->bar_windows);
+    log_printf ("    last_bar_windows. . : 0x%lx", GUI_WINDOW_OBJECTS(window)->last_bar_window);
+    log_printf ("    current_style_fg. . : %d",    GUI_WINDOW_OBJECTS(window)->current_style_fg);
+    log_printf ("    current_style_bg. . : %d",    GUI_WINDOW_OBJECTS(window)->current_style_bg);
+    log_printf ("    current_style_attr. : %d",    GUI_WINDOW_OBJECTS(window)->current_style_attr);
+    log_printf ("    current_color_attr. : %d",    GUI_WINDOW_OBJECTS(window)->current_color_attr);
 }
